@@ -57,14 +57,14 @@ extern crate libc_print;
 #[doc(hidden)]
 pub mod macros;
 
-#[cfg(not(doc))]
+#[cfg(all(not(doc), not(test)))]
 pub mod panic;
 
 mod output;
 
 //////////////////////////////////////////////
 
-#[cfg(not(doc))]
+#[cfg(all(not(doc), not(test)))]
 pub fn crash(file: &str, line: u32, column: u32, arguments: Option<&Arguments>) -> ! {
     panic::cx_panic(&PanicInfo::internal_constructor(
         arguments,
@@ -73,7 +73,7 @@ pub fn crash(file: &str, line: u32, column: u32, arguments: Option<&Arguments>)
     ))
 }
 
-#[cfg(doc)]
+#[cfg(any(doc, test))]
 #[doc(hidden)]
 pub fn crash(_: &str, _: u32, _: u32, _: Option<&Arguments>) -> ! {
     loop {}
@@ -123,7 +123,7 @@ pub enum Outcome<'o> {
 /// - test_func: The function to call for the test, must be like _() {} (without return value).
 /// - ignored: Indicates of the test should be ignored.
 /// - should_panic: Indicates if the test should panic, if true, then a panicking test will be marked as success
-pub struct UnitTest<'u> {
+pub struct TestBlock<'u> {
     pub name: &'u str,
     pub test_func: fn(),
     pub ignored: bool,
@@ -164,14 +164,26 @@ pub struct State<'s, T: Output> {
     pub panic: bool,
     pub msg: Option<&'s str>,
     printer: Mutex<T>,
-    tests: Option<&'s [&'s UnitTest<'s>]>,
-    current: Option<&'s UnitTest<'s>>,
+    tests: Option<&'s [&'s TestBlock<'s>]>,
+    current: Option<&'s TestBlock<'s>>,
     conclusion: Option<Conclusion>,
     counter: usize,
 }
 
 cfg_if::cfg_if! {
-    if #[cfg(feature = "pretty")] {
+    if #[cfg(test)] {
+        lazy_static! {
+            pub static ref STATE: RwLock<State<'static, output::dummy::Dummy>> = spin::RwLock::new(State {
+                panic: false,
+                msg: None,
+                printer: spin::Mutex::new(output::dummy::Dummy::new()),
+                tests: None,
+                current: None,
+                conclusion: None,
+                counter: 0
+            });
+        }
+    } else if #[cfg(feature = "pretty")] {
         lazy_static! {
             pub static ref STATE: RwLock<State<'static, output::pretty::Pretty>> = spin::RwLock::new(State {
                 panic: false,
@@ -212,7 +224,7 @@ cfg_if::cfg_if! {
 
 //////////////////////////////////////////////
 
-pub fn test_runner(tests: &'static [&'static UnitTest<'static>]) {
+pub fn test_runner(tests: &'static [&'static TestBlock<'static>]) {
     // Initialization
     {
         let mut state = STATE.write();
@@ -280,3 +292,29 @@ pub fn test_runner(tests: &'static [&'static UnitTest<'static>]) {
         .lock()
         .print_summary(STATE.read().conclusion.as_ref().unwrap());
 }
+
+//////////////////////////////////////////////
+/*
+#[cfg(test)]
+mod test {
+    extern crate std;
+    use super::*;
+
+    fn dummy_test_fn() {}
+    const DUMMY: TestBlock = TestBlock {
+        name: "my dummy test",
+        test_func: dummy_test_fn,
+        ignored: false,
+        should_panic: false
+    };
+
+    #[test]
+    fn test_empty() {
+        test_runner(&[]);
+    }
+
+    #[test]
+    fn test_normal() {
+        test_runner(&[&DUMMY]);
+    }
+}*/
